Index: uspace/drv/bus/usb/ehci/ehci_bus.c
===================================================================
--- uspace/drv/bus/usb/ehci/ehci_bus.c	(revision a4e2688242f9b376a6077b18fc9e81977110922c)
+++ uspace/drv/bus/usb/ehci/ehci_bus.c	(revision ee794529392e0d007ecfbb2eb6d719532ea0aba0)
@@ -129,5 +129,5 @@
 }
 
-static int ehci_release_ep(bus_t *bus_base, endpoint_t *ep)
+static int ehci_unregister_ep(bus_t *bus_base, endpoint_t *ep)
 {
 	ehci_bus_t *bus = (ehci_bus_t *) bus_base;
@@ -135,5 +135,5 @@
 	assert(ep);
 
-	const int err = bus->parent_ops.release_endpoint(bus_base, ep);
+	const int err = bus->parent_ops.unregister_endpoint(bus_base, ep);
 	if (err)
 		return err;
@@ -170,5 +170,5 @@
 
 	ops->register_endpoint = ehci_register_ep;
-	ops->release_endpoint = ehci_release_ep;
+	ops->unregister_endpoint = ehci_unregister_ep;
 
 	ops->create_batch = ehci_bus_create_batch;
Index: uspace/drv/bus/usb/ohci/ohci_bus.c
===================================================================
--- uspace/drv/bus/usb/ohci/ohci_bus.c	(revision a4e2688242f9b376a6077b18fc9e81977110922c)
+++ uspace/drv/bus/usb/ohci/ohci_bus.c	(revision ee794529392e0d007ecfbb2eb6d719532ea0aba0)
@@ -130,5 +130,5 @@
 }
 
-static int ohci_release_ep(bus_t *bus_base, endpoint_t *ep)
+static int ohci_unregister_ep(bus_t *bus_base, endpoint_t *ep)
 {
 	ohci_bus_t *bus = (ohci_bus_t *) bus_base;
@@ -136,5 +136,5 @@
 	assert(ep);
 
-	const int err = bus->parent_ops.release_endpoint(bus_base, ep);
+	const int err = bus->parent_ops.unregister_endpoint(bus_base, ep);
 	if (err)
 		return err;
@@ -170,5 +170,5 @@
 
 	ops->register_endpoint = ohci_register_ep;
-	ops->release_endpoint = ohci_release_ep;
+	ops->unregister_endpoint = ohci_unregister_ep;
 
 	ops->create_batch = ohci_bus_create_batch;
Index: uspace/drv/bus/usb/xhci/bus.c
===================================================================
--- uspace/drv/bus/usb/xhci/bus.c	(revision a4e2688242f9b376a6077b18fc9e81977110922c)
+++ uspace/drv/bus/usb/xhci/bus.c	(revision ee794529392e0d007ecfbb2eb6d719532ea0aba0)
@@ -118,5 +118,5 @@
 	xhci_device_t *xhci_dev = xhci_device_get(dev);
 
 	/* Release remaining endpoints. */
 	for (size_t i = 0; i < ARRAY_SIZE(xhci_dev->endpoints); ++i) {
 		if (!xhci_dev->endpoints[i])
@@ -124,5 +124,5 @@
 
 		// FIXME: ignoring return code
-		bus_release_endpoint(&bus->base, &xhci_dev->endpoints[i]->base);
+		bus_unregister_endpoint(&bus->base, &xhci_dev->endpoints[i]->base);
 	}
 
@@ -257,10 +257,10 @@
 }
 
-static int release_endpoint(bus_t *bus_base, endpoint_t *ep)
+static int unregister_endpoint(bus_t *bus_base, endpoint_t *ep)
 {
 	xhci_bus_t *bus = bus_to_xhci_bus(bus_base);
 	assert(bus);
 
-	usb_log_info("Endpoint(%d:%d) released from XHCI bus.", ep->target.address, ep->target.endpoint);
+	usb_log_info("Endpoint(%d:%d) unregistered from XHCI bus.", ep->target.address, ep->target.endpoint);
 
 	xhci_device_t *xhci_dev = xhci_device_get(ep->device);
@@ -329,5 +329,5 @@
 
 	.register_endpoint = register_endpoint,
-	.release_endpoint = release_endpoint,
+	.unregister_endpoint = unregister_endpoint,
 	.find_endpoint = find_endpoint,
 
@@ -118,5 +118,5 @@
 	xhci_device_t *xhci_dev = xhci_device_get(dev);
 
-	/* Release remaining endpoints. */
+	/* Unregister remaining endpoints. */
 	for (size_t i = 0; i < ARRAY_SIZE(xhci_dev->endpoints); ++i) {
 		if (!xhci_dev->endpoints[i])
